<?php
/**
 * @file
 * Admin forms for RoyalSlider.
 */

/**
 * Submit handler for adding a new option set.
 */
function royalslider_form_optionset_add_submit($form, &$form_state) {
  $optionset = royalslider_optionset_create(array('name' => $form_state['values']['name'], 'title' => $form_state['values']['title']));

  $saved = royalslider_optionset_save($optionset, TRUE);

  if ($saved) {
    drupal_set_message(t('Option set %name was created.', array('%name' => $optionset->name)));
    $form_state['redirect'] = 'admin/config/media/royalslider/edit/' . $optionset->name;
  }
  else {
    drupal_set_message(t('Failed to create option set. Please verify your settings.'), 'error');
  }
}


/**
 * Defines the form elements used to edit the RoyalSlider library options
 *
 * @param array $options [optional]
 *  Pass in a set of default values for the options
 * @return array
 *  Returns the option set array
 */
function royalslider_option_elements($options = array()) {
  // For whatever reason, the only way to get #tree behavior to work here is by]
  // explicitly setting the #parents array. Also setting #tree to true in the
  // top-level form is causing a fatal error.
  $form = array();

  $form['intro'] = array(
    '#markup' => t("For more information on the RoyalSlider options, please refer to the <a href=\"@link\">official documentation</a>.", array('@link' => 'http://dimsemenov.com/plugins/royal-slider/documentation/')),
  );

  // General options.
  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General'),
  );

  $form['general']['loop'] = array(
    '#type' => 'checkbox',
    '#title' => t('Loop'),
    '#description' => t('Makes slider to go from last slide to first.'),
    '#default_value' => isset($options['loop'])
      ? $options['loop']
      : FALSE,
  );

  $form['general']['loopRewind'] = array(
    '#type' => 'checkbox',
    '#title' => t('Loop rewind'),
    '#description' => t('Makes slider to go from last slide to first with rewind. Overrides previous option.'),
    '#default_value' => isset($options['loopRewind'])
      ? $options['loopRewind']
      : FALSE,
  );

  $form['general']['randomizeSlides'] = array(
    '#type' => 'checkbox',
    '#title' => t('Randomize slides'),
    '#description' => t('Randomizes all slides at start.'),
    '#default_value' => isset($options['randomizeSlides'])
      ? $options['randomizeSlides']
      : FALSE,
  );

  $form['general']['usePreloader'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Preloader'),
    '#description' => t('Enables spinning preloader, you may style it via CSS (class rsPreloader)'),
    '#default_value' => isset($options['usePreloader'])
      ? $options['usePreloader']
      : TRUE,
  );

  $form['general']['numImagesToPreload'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of images to preload'),
    '#description' => t('Number of images to preload on sides. If you set it to 0, only one slide will be kept in the display list at once.'),
    '#size' => 3,
    '#default_value' => isset($options['numImagesToPreload'])
      ? $options['numImagesToPreload']
      : '4',
    '#states' => array(
      'visible' => array(
        'input[name="usePreloader"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['general']['slidesOrientation'] = array(
    '#type' => 'textfield',
    '#title' => t('Slide orientation'),
    '#options' => array(
      'horizontal' => t('Horizontal'),
      'vertical' => t('Vertical'),
    ),
    '#default_value' => isset($options['slidesOrientation'])
      ? $options['slidesOrientation']
      : 'horizontal',
  );

  $form['general']['globalCaption'] = array(
    '#type' => 'checkbox',
    '#title' => t('Global caption'),
    '#description' => t('Adds global caption element to slider.'),
    '#default_value' => isset($options['globalCaption'])
      ? $options['globalCaption']
      : TRUE,
  );

  // Full Screen mode.
  $form['fullscreen'] = array(
    '#type' => 'fieldset',
    '#title' => t('Full Screen'),
    '#tree' => TRUE,
  );

  $form['fullscreen']['enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enabled'),
    '#description' => t('Enable Full Screen mode.'),
    '#default_value' => isset($options['fullscreen']['enabled'])
      ? $options['fullscreen']['enabled']
      : FALSE,
    '#parents' => array('fullscreen', 'enabled'),
  );

  $form['fullscreen']['keyboardNav'] = array(
    '#type' => 'checkbox',
    '#title' => t('Force keyboard arrows nav in fullscreen'),
    '#default_value' => isset($options['fullscreen']['keyboardNav'])
      ? $options['fullscreen']['keyboardNav']
      : TRUE,
    '#states' => array(
      'visible' => array(
        'input[name="fullscreen[enabled]"]' => array('checked' => TRUE),
      ),
    ),
    '#parents' => array('fullscreen', 'keyboardNav'),
  );

  $form['fullscreen']['buttonFS'] = array(
    '#type' => 'checkbox',
    '#title' => t('Fullscreen button at top right'),
    '#default_value' => isset($options['fullscreen']['buttonFS'])
      ? $options['fullscreen']['buttonFS']
      : TRUE,
    '#states' => array(
      'visible' => array(
        'input[name="fullscreen[enabled]"]' => array('checked' => TRUE),
      ),
    ),
    '#parents' => array('fullscreen', 'buttonFS'),
  );

  $form['fullscreen']['nativeFS'] = array(
    '#type' => 'checkbox',
    '#title' => t('Native browser full screen.'),
    '#description' => t('Enable native browser full screen mode, if available.'),
    '#default_value' => isset($options['fullscreen']['nativeFS'])
      ? $options['fullscreen']['nativeFS']
      : FALSE,
    '#states' => array(
      'visible' => array(
        'input[name="fullscreen[enabled]"]' => array('checked' => TRUE),
      ),
    ),
    '#parents' => array('fullscreen', 'nativeFS'),
  );

  // Navigation.
  $form['navigation'] = array(
    '#type' => 'fieldset',
    '#title' => t('Navigation'),
  );

  $form['navigation']['controlNavigation'] = array(
    '#title' => t('Navigation type'),
    '#type' => 'select',
    '#options' => array(
      'none' => t('None'),
      'bullets' => t('Bullets'),
      'tabs' => t('Tabs'),
      'thumbnails' => t('Thumbnails'),
    ),
    '#default_value' => isset($options['controlNavigation'])
      ? $options['controlNavigation'] : 'bullets',
  );

  $form['navigation']['controlsInside'] = array(
    '#title' => t('Controls inside'),
    '#description' => t('If set to true adds arrows and fullscreen button inside rsOverflow container, otherwise inside root slider container.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['controlsInside'])
      ? $options['controlsInside'] : TRUE,
  );

  $form['navigation']['sliderDrag'] = array(
    '#title' => t('Mouse drag navigation over slider'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['sliderDrag'])
      ? $options['sliderDrag'] : TRUE,
  );

  $form['navigation']['sliderTouch'] = array(
    '#title' => t('Touch navigation of slider'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['sliderTouch'])
      ? $options['sliderTouch'] : TRUE,
  );

  $form['navigation']['keyboardNavEnabled'] = array(
    '#title' => t('Keyboard navigation'),
    '#description' => t('Navigate slider with keyboard left and right arrows.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['keyboardNavEnabled'])
      ? $options['keyboardNavEnabled'] : FALSE,
  );

  $form['navigation']['navigateByClick'] = array(
    '#title' => t('Click navigation'),
    '#description' => t('Navigates forward by clicking on slide.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['navigateByClick'])
      ? $options['navigateByClick'] : TRUE,
  );

  $form['navigation']['arrowsNav'] = array(
    '#title' => t('Navigation arrows'),
    '#description' => t('Direction arrows navigation'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['arrowsNav'])
      ? $options['arrowsNav'] : TRUE,
  );

  $form['navigation']['arrowsNavAutoHide'] = array(
    '#title' => t('Auto hide arrows'),
    '#description' => t('Auto hide arrows when focus is lost'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['arrowsNavAutoHide'])
      ? $options['arrowsNavAutoHide'] : TRUE,
    '#states' => array(
      'visible' => array(
        'input[name="arrowsNav"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['navigation']['arrowsNavHideOnTouch'] = array(
    '#title' => t('Hide on touch'),
    '#description' => t('Hide arrows completely on touch devices'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['arrowsNavHideOnTouch'])
      ? $options['arrowsNavHideOnTouch'] : FALSE,
    '#states' => array(
      'visible' => array(
        'input[name="arrowsNav"]' => array('checked' => TRUE),
      ),
    ),
  );

  // Thumbnails.
  $form['thumbs'] = array(
    '#type' => 'fieldset',
    '#title' => t('Thumbnails'),
    '#description' => t('These settings will only apply if Navigation type is set to "thumbnails".'),
    '#tree' => TRUE,
  );

  $form['thumbs']['drag'] = array(
    '#title' => t('Thumbnails mouse drag'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['drag'])
      ? $options['thumbs']['drag'] : TRUE,
    '#parents' => array('thumbs', 'drag'),
  );

  $form['thumbs']['touch'] = array(
    '#title' => t('Thumbnails touch'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['touch'])
      ? $options['thumbs']['touch'] : TRUE,
    '#parents' => array('thumbs', 'touch'),
  );

  $form['thumbs']['orientation'] = array(
    '#title' => t('Orientation'),
    '#type' => 'select',
    '#options' => array(
      'horizontal' => t('Horizontal'),
      'vertical' => t('Vertical'),
    ),
    '#default_value' => isset($options['thumbs']['orientation'])
      ? $options['thumbs']['orientation'] : 'horizontal',
    '#parents' => array('thumbs', 'orientation'),
  );

  $form['thumbs']['arrows'] = array(
    '#title' => t('Thumbnail arrows'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['arrows'])
      ? $options['thumbs']['arrows'] : TRUE,
    '#parents' => array('thumbs', 'arrows'),
  );

  $form['thumbs']['spacing'] = array(
    '#title' => t('Spacing between thumbs'),
    '#type' => 'textfield',
    '#default_value' => isset($options['thumbs']['spacing'])
      ? $options['thumbs']['spacing'] : '4',
    '#size' => 3,
    '#parents' => array('thumbs', 'spacing'),
  );

  $form['thumbs']['arrowsAutoHide'] = array(
    '#title' => t('Auto hide arrows'),
    '#description' => t('Auto hide thumbnails arrows on hover.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['arrowsAutoHide'])
      ? $options['thumbs']['arrowsAutoHide'] : FALSE,
    '#parents' => array('thumbs', 'arrowsAutoHide'),
  );

  $form['thumbs']['autoCenter'] = array(
    '#title' => t('Auto center'),
    '#description' => t('Automatically centers container with thumbs if there are small number of items.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['autoCenter'])
      ? $options['thumbs']['autoCenter'] : TRUE,
    '#parents' => array('thumbs', 'autoCenter'),
  );

  $form['thumbs']['transitionSpeed'] = array(
    '#title' => t('Transition speed'),
    '#description' => t('Thumbnails transition speed, in milliseconds.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['thumbs']['transitionSpeed'])
      ? $options['thumbs']['transitionSpeed'] : '600',
    '#size' => 5,
    '#parents' => array('thumbs', 'transitionSpeed'),
  );

  $form['thumbs']['fitInViewport'] = array(
    '#title' => t('Fit in viewport'),
    '#description' => t('Reduces size of main viewport area by thumbnails width or height, use it when you set 100% width to slider. This option is always true, when slider is in fullscreen mode.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['fitInViewport'])
      ? $options['thumbs']['fitInViewport'] : TRUE,
    '#parents' => array('thumbs', 'fitInViewport'),
  );

  $form['thumbs']['firstMargin'] = array(
    '#title' => t('First margin'),
    '#description' => t('Margin that equals thumbs spacing for first and last item.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['firstMargin'])
      ? $options['thumbs']['firstMargin'] : TRUE,
    '#parents' => array('thumbs', 'firstMargin'),
  );

  $form['thumbs']['arrowLeft'] = array(
    '#title' => t('Replace left thumbnail arrow'),
    '#description' => t('Replaces default thumbnail arrow. Variable accepts jQuery element $(\'This is left arrow\') that will be used as arrow. You have to add it to DOM manually.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['thumbs']['arrowLeft'])
      ? $options['thumbs']['arrowLeft'] : '',
    '#parents' => array('thumbs', 'arrowLeft'),
  );

  $form['thumbs']['arrowRight'] = array(
    '#title' => t('Replace right thumbnail arrow'),
    '#description' => t('Replaces default thumbnail arrow. Variable accepts jQuery element $(\'This is left arrow\') that will be used as arrow. You have to add it to DOM manually.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['thumbs']['arrowRight'])
      ? $options['thumbs']['arrowRight'] : '',
    '#parents' => array('thumbs', 'arrowRight'),
  );

  $form['thumbs']['appendSpan'] = array(
    '#title' => t('Append Span'),
    '#description' => t('Adds span element with class "thumbIco" to every thumbnail. Useful for styling.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['thumbs']['appendSpan'])
      ? $options['thumbs']['appendSpan'] : FALSE,
    '#parents' => array('thumbs', 'appendSpan'),
  );

  // Transitions.
  $form['transitions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Transitions'),
  );

  $form['transitions']['transitionType'] = array(
    '#title' => t('Transition type'),
    '#description' => t('Important note about fade transition, slides must have background as only one image is animating.'),
    '#type' => 'select',
    '#options' => array(
      'move' => t('Move'),
      'fade' => t('Fade'),
    ),
    '#default_value' => isset($options['transitionType'])
      ? $options['transitionType'] : 'move',
  );

  $form['transitions']['transitionSpeed'] = array(
    '#title' => t('Transition speed'),
    '#description' => t('Slider transition speed, in milliseconds.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['transitionSpeed'])
      ? $options['transitionSpeed'] : '600',
    '#size' => 5,
  );

  $form['transitions']['easeInOut'] = array(
    '#title' => t('Easing function for simple transition'),
    '#type' => 'textfield',
    '#default_value' => isset($options['easeInOut'])
      ? $options['easeInOut'] : 'easeInOutSine',
    '#size' => 5,
  );

  $form['transitions']['easeOut'] = array(
    '#title' => t('Easing function of animation after ending of the swipe gesture'),
    '#type' => 'textfield',
    '#default_value' => isset($options['easeOut'])
      ? $options['easeOut'] : 'easeOutSine',
    '#size' => 5,
  );

//  // Build in support for easing plugin
//  $easing_options = array('swing' => t('Swing'), 'linear' => t('Linear'));
//  if (module_exists('jqeasing')) {
//    $easing_options = array_merge($easing_options, _royalslider_jqeasing_options());
//  }
//
//  $form['animation_slideshow']['easing'] = array(
//    '#type' => 'select',
//    '#title' => t('Easing'),
//    '#multiple' => FALSE,
//    '#description' => t('The description appears usually below the item.'),
//    '#options' => $easing_options,
//    '#default_value' => isset($options['easing']) ? $options['easing'] : _royalslider_optionset_defaults('easing'),
//  );

  $form['transitions']['allowCSS3'] = array(
    '#title' => t('Allows usage of CSS3 transitions'),
    '#description' => t('Might be useful if you\'re experiencing font-rendering problems, or other CSS3-related bugs.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['allowCSS3'])
      ? $options['allowCSS3'] : TRUE,
  );

  $form['transitions']['addActiveClass'] = array(
    '#title' => t('Add active class'),
    '#description' => t('Adds rsActiveSlide class to current slide before transition.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['addActiveClass'])
      ? $options['addActiveClass'] : FALSE,
  );

  $form['transitions']['fadeinLoadedSlide'] = array(
    '#title' => t('Fades in slides'),
    '#description' => t('Fades in slide after it\'s loaded'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['fadeinLoadedSlide'])
      ? $options['fadeinLoadedSlide'] : TRUE,
  );

  // Dimensions.
  $form['dimensions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Dimensions'),
  );

  $form['dimensions']['autoScaleSlider'] = array(
    '#title' => t('Auto scale slider'),
    '#description' => t('Automatically updates slider height based on base width.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['autoScaleSlider'])
      ? $options['autoScaleSlider'] : FALSE,
  );

  $form['dimensions']['drupalAutoSetDimensions'] = array(
    '#title' => t('Automatically calculate image dimensions'),
    '#description' => t('This is a Drupal-specific option. We can calculate an image\'s dimensions using GD and set them as RoyalSlider attributes.'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['drupalAutoSetDimensions'])
      ? $options['drupalAutoSetDimensions'] : FALSE,
    '#states' => array(
      'visible' => array(
        'input[name="autoScaleSlider"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['dimensions']['autoScaleSliderWidth'] = array(
    '#title' => t('Base slider width'),
    '#description' => t('Slider will autocalculate the ratio based on these values.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['autoScaleSliderWidth'])
      ? $options['autoScaleSliderWidth'] : '800',
    '#states' => array(
      'visible' => array(
        'input[name="autoScaleSlider"]' => array('checked' => TRUE),
        'input[name="drupalAutoSetDimensions"]' => array('checked' => FALSE),
      ),
    ),
  );

  $form['dimensions']['autoScaleSliderHeight'] = array(
    '#title' => t('Base slider height'),
    '#description' => t('Slider will autocalculate the ratio based on these values.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['autoScaleSliderHeight'])
      ? $options['autoScaleSliderHeight'] : '400',
    '#states' => array(
      'visible' => array(
        'input[name="autoScaleSlider"]' => array('checked' => TRUE),
        'input[name="drupalAutoSetDimensions"]' => array('checked' => FALSE),
      ),
    ),
  );

  $form['dimensions']['imageScaleMode'] = array(
    '#title' => t('Scale mode for images'),
    '#type' => 'select',
    '#options' => array(
      'none' => t('None'),
      'fill' => t('Fill'),
      'fit' => t('Fit'),
      'fit-if-smaller' => t('Fit if smaller'),
    ),
    '#default_value' => isset($options['imageScaleMode'])
      ? $options['imageScaleMode'] : 'fit-if-smaller',
    '#states' => array(
      'visible' => array(
        'input[name="autoScaleSlider"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['dimensions']['imageScalePadding'] = array(
    '#title' => t('Scale padding'),
    '#description' => t('Distance between image and edge of slide (doesn\'t work with \'fill\' scale mode).'),
    '#type' => 'textfield',
    '#default_value' => isset($options['imageScalePadding'])
      ? $options['imageScalePadding'] : '4',
    '#size' => 3,
    '#states' => array(
      'visible' => array(
        'input[name="autoScaleSlider"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['dimensions']['imageAlignCenter'] = array(
    '#title' => t('Aligns image to center of slide'),
    '#type' => 'checkbox',
    '#default_value' => isset($options['imageAlignCenter'])
      ? $options['imageAlignCenter'] : TRUE,
  );

  $form['dimensions']['imgWidth'] = array(
    '#title' => t('Image width'),
    '#description' => t('Adds base width to all images for better-looking loading.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['imgWidth'])
      ? $options['imgWidth'] : '',
    '#size' => 5,
  );

  $form['dimensions']['imgHeight'] = array(
    '#title' => t('Image height'),
    '#description' => t('Adds base height to all images for better-looking loading.'),
    '#type' => 'textfield',
    '#default_value' => isset($options['imgHeight'])
      ? $options['imgHeight'] : '',
    '#size' => 5,
  );

  return $form;
}

/**
 * Form builder; Form to edit a given option set.
 */
function royalslider_form_optionset_edit($form, &$form_state) {

  if (empty($form_state['optionset'])) {
    $optionset = royalslider_optionset_create();
  }
  else {
    $optionset = $form_state['optionset'];
  }

  // Title
  $form['title'] = array(
    '#type' => 'textfield',
    '#maxlength' => '255',
    '#title' => t('Title'),
    '#description' => t('A human-readable title for this option set.'),
    '#required' => TRUE,
    '#default_value' => $optionset->title,
  );

  // Machine name.
  $form['name'] = array(
    '#type' => 'machine_name',
    '#maxlength' => '255',
    '#machine_name' => array(
      'source' => array('title'),
      'exists' => 'royalslider_optionset_exists',
    ),
    '#required' => TRUE,
    '#default_value' => $optionset->name,
  );

  // Skin.
  $skins = array();

  foreach(royalslider_skins() as $name => $info) {
    $skins[$name] = $info['name'];
  }

  $form['skin'] = array(
    '#type' => 'select',
    '#title' => t('Skin'),
    '#options' => $skins,
    '#default_value' => $optionset->skin,
  );

  // Show select boxes for the various image styles.
  $image_style = image_style_options(FALSE);

  $form['image_style'] = array(
    '#type' => 'fieldset',
    '#title' => t('Image styles'),
    '#tree' => TRUE,
  );
  $form['image_style']['fullscreen'] = array(
    '#type' => 'select',
    '#title' => t('Full Screen image style'),
    '#description' => t('Image style for the full screen images.'),
    '#empty_option' => t('None (original image)'),
    '#options' => $image_style,
    '#default_value' => $optionset->imagestyle_fullscreen,
    '#states' => array(
      'visible' => array(
        'input[name="fullscreen[enabled]"]' => array('checked' => TRUE),
      ),
    ),
  );
  $form['image_style']['normal'] = array(
    '#type' => 'select',
    '#title' => t('Normal image style'),
    '#description' => t('Image style for the main stage images.'),
    '#empty_option' => t('None (original image)'),
    '#options' => $image_style,
    '#default_value' => $optionset->imagestyle_normal,
  );
  $form['image_style']['thumbnail'] = array(
    '#type' => 'select',
    '#title' => t('Thumbnail image style'),
    '#description' => t('Image style for the thumbnail images.'),
    '#empty_option' => t('None (original image)'),
    '#options' => $image_style,
    '#default_value' => $optionset->imagestyle_thumbnail,
    '#states' => array(
      'visible' => array(
        'select[name="controlNavigation"]' => array('value' => 'thumbnails'),
      ),
    ),
  );

  // Options Vertical Tab Group table
  $form['options'] = array(
    '#type' => 'vertical_tabs',
  );

  $default_options = royalslider_option_elements($optionset->options);
  // Add the options to the vertical tabs section
  foreach ($default_options as $key => $value) {
    $form['options'][] = $value;
  }

  return $form;
}

/**
 * Form builder; Form to delete a given option set.
 */
function royalslider_optionset_form_delete($form, &$form_state, $optionset) {
  $form_state['optionset'] = &$optionset;

  // Deleting an export in code will revert it.
  $op = ($optionset->export_type & EXPORT_IN_CODE) ? 'Revert' : 'Delete';

  return confirm_form(
    $form,
    t('Are you sure you want to @action the option set %name?', array('@action' => t(drupal_strtolower($op)), '%name' => $optionset->name)),
    'admin/config/media/royalslider',
    NULL,
    t($op),  t('Cancel')
  );
}

/**
 * Submit handler for deleting an option set.
 */
function royalslider_optionset_form_delete_submit($form, &$form_state) {
  $optionset = &$form_state['optionset'];
  $op = ($optionset->export_type & EXPORT_IN_CODE) ? 'reverted' : 'deleted';

  ctools_include('export');
  ctools_export_crud_delete('royalslider_optionset', $optionset);

  drupal_set_message(t('Option set %name was ' . $op . '.', array('%name' => $optionset->name)));
  $form_state['redirect'] = 'admin/config/media/royalslider';
}
