<?php
/**
 * @file
 * Theme functions for RoyalSlider.
 */

/**
* Implements hook_preprocess_HOOK().
*
* Preprocess variables for the RoyalSlider template.
*/
function royalslider_preprocess_royalslider(&$variables) {
  // Load optionset.
  if ($optionset = ctools_export_crud_load('royalslider_optionset', $variables['optionset'])) {
    $variables['settings'] = $optionset->options;

    // Add wrapper attributes.
    $variables['attributes_array']['class'][] = 'royalSlider';
    $variables['attributes_array']['id'] = $variables['royalslider_id'];

    // Setup skin & fallback to default.
    $skin = !empty($variables['skin']) ? $variables['skin'] : $optionset->skin;
    $skins = royalslider_skins();

    $skin_class = isset($skins[$skin]['class'])
      ? $skins[$skin]['class']
      : $skins['default']['class'];

    $variables['attributes_array']['class'][] = $skin_class;

    // Now prepare items for rendering.
    $items_processed = array();

    foreach ($variables['items'] as $item) {
      $items_processed[] = array(
        '#theme' => 'royalslider_item',
        '#royalslider_id' => $variables['royalslider_id'],
        '#optionset' => $optionset,
        '#item' => $item,
      );
    }

    $variables['items_processed'] = $items_processed;

    if (!empty($items_processed)) {
      // Add resources.
      royalslider_add($variables['royalslider_id'], $optionset, $skin);

      // We're done!
      return;
    }
  }
}

/**
 * Implements hook_preprocess_HOOK().
 *
 * Preprocess variables for the RoyalSlider Item template.
 */
function royalslider_preprocess_royalslider_item(&$variables) {
  $optionset = $variables['optionset'];
  $item = $variables['item'];

  // Tag is defined by optionset, not individual item.
  $variables['tag'] = $optionset->options['usePreloader'] ? 'a' : 'img';

  $attributes = array('class' => array('rsImg'));

  $variables['caption'] = $item['alt'];

  // Set image dimensions.
  if ($optionset->options['autoScaleSlider']) {
    // Calculate automatically.
    if ($optionset->options['drupalAutoSetDimensions']) {
      $dimensions = array(
        'width' => $item['width'],
        'height' => $item['height'],
      );

      if (!empty($optionset->imagestyle_normal)) {
        image_style_transform_dimensions($optionset->imagestyle_normal, $dimensions);
      }
    }
    // Hard-coded by options.
    else {
      $dimensions = array(
        'width' => $optionset->options['autoScaleSliderWidth'],
        'height' => $optionset->options['autoScaleSliderHeight'],
      );
    }

    $attributes['data-rsw'] = $dimensions['width'];
    $attributes['data-rsh'] = $dimensions['height'];
  }

  // Handle full-screen images.
  if ($optionset->options['fullscreen']['enabled']) {
    $image_style = $optionset->imagestyle_fullscreen;

    $attributes['data-rsBigImg'] = !empty($image_style)
      ? _royalslider_image_style($image_style, $item['uri'])
      : file_create_url($item['uri']);
  }

  // Handle thumbnail images.
  if ($optionset->options['controlNavigation'] === 'thumbnails') {
    $image_style = $optionset->imagestyle_thumbnail;

    $attributes['data-rsTmb'] = !empty($image_style)
      ? _royalslider_image_style($image_style, $item['uri'])
      : file_create_url($item['uri']);
  }

  // Set main image url.
  $image_style = $optionset->imagestyle_normal;
  $variables['url'] = !empty($image_style)
    ? _royalslider_image_style($image_style, $item['uri'])
    : file_create_url($item['uri']);

  // Finally, set attributes.
  $variables['attributes_array'] = $attributes;
}

/**
 * Remote Stream Wrapper-aware helper function to apply Drupal image styles
 * to image URIs.
 *
 * @param string
 *   The image style we want to apply.
 * @param string
 *   The image's URI.
 *
 * @return string
 *   The image's path.
 */
function _royalslider_image_style($image_style, $uri) {
  // Compatibility with Remote Stream Wrapper.
  static $remote_stream_wrapper;

  if (!isset($remote_stream_wrapper)) {
    $remote_stream_wrapper = module_exists('remote_stream_wrapper');
  }

  if ($remote_stream_wrapper) {
    $path = file_is_scheme_remote(file_uri_scheme($uri))
      ? remote_stream_wrapper_image_style_path($image_style, $uri)
      : image_style_url($image_style, $uri);
  }
  else {
    $path = image_style_url($image_style, $uri);
  }

  return $path;
}
